@@ -2,7 +2,7 @@
 
 package Plack::Middleware::HTMLMinify;
 BEGIN {
-  $Plack::Middleware::HTMLMinify::VERSION = '0.5';
+  $Plack::Middleware::HTMLMinify::VERSION = '1.0.0';
 }
 
 use strict;
@@ -14,7 +14,7 @@ Plack::Middleware::HTMLMinify - Plack middleware for HTML minify
 
 =head1 VERSION
 
-version 0.5
+version 1.0.0
 
 =head1 DESCRIPTION
 
@@ -25,7 +25,7 @@ automatically.  Currently it will check if Content-Type is C<text/html>.
 
     use Plack::Builder;
     builder {
-	enable 'HTMLMinify', opt => {remove_newlines => 1};
+        enable 'HTMLMinify', opt => {remove_newlines => 1};
     }
 
 =cut
@@ -42,29 +42,28 @@ sub call {
 
     my $res = $self->app->($env);
     Plack::Util::response_cb($res, sub {
-	my $res = shift;
+        my $res = shift;
 
-	my $h = Plack::Util::headers($res->[1]);
+        my $h = Plack::Util::headers($res->[1]);
 
-	# Only process text/html.
-	return unless $h->get('Content-Type') =~ qr{text/html};
+        # Only process text/html.
+        my $ct = $h->get('Content-Type');
+        return unless defined $ct and $ct =~ qr{text/html};
 
-	# Don't touch compressed content.
-	return if defined $h->get('Content-Encoding');
+        # Don't touch compressed content.
+        return if defined $h->get('Content-Encoding');
 
-	# Concat all content, and if response body is undefined then ignore it.
-	my $body = [];
-	Plack::Util::foreach($res->[2], sub { push @$body, $_[0]; });
-	$body = join '', @$body;
+        # Concat all content, and if response body is undefined then ignore it.
+        my $body = [];
+        Plack::Util::foreach($res->[2], sub { push @$body, $_[0]; });
+        $body = join '', @$body;
 
-	return if '' eq $body;
+        # Minify and replace it.
+        $self->packer->minify(\$body, $self->opt) if '' ne $body;
+        $res->[2] = [$body];
+        $h->set('Content-Length', length $body);
 
-	# Minify and replace it.
-	$self->packer->minify(\$body, $self->opt);
-	$res->[2] = [$body];
-	$h->set('Content-Length', length $body);
-
-	return;
+        return;
     });
 }
 
